@@ -1,7 +1,7 @@
 /**************************************************************************\
  *
  *  This file is part of the Coin 3D visualization library.
- *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
+ *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -16,7 +16,7 @@
  *
  *  See <URL:http://www.coin3d.org/> for more information.
  *
- *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
+ *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
  *  <URL:http://www.sim.no/>.
  *
 \**************************************************************************/
@@ -228,6 +228,10 @@
 #include <config.h>
 #endif // HAVE_CONFIG_H
 
+// FIXME: get rid of this define. We should fix up the compile issues
+// wrt Qt 4 properly. 20050629 mortene.
+#define QT3_SUPPORT
+
 #include <stdlib.h>
 #include <limits.h>
 
@@ -240,6 +244,9 @@
 
 #ifdef Q_WS_X11
 #include <X11/Xlib.h>
+#if QT_VERSION >= 0x040000 // Qt 4.0.0+
+#include <qx11info_x11.h> // for QX11Info
+#endif // Qt 4.0.0+
 #endif // Q_WS_X11
 
 #include <Inventor/SoDB.h>
@@ -250,7 +257,6 @@
 
 #include <Inventor/Qt/SoQtP.h>
 #include <Inventor/Qt/moc_SoQtP.icc>
-/*[ src\Inventor\Qt\SoQtP.h | src\Inventor\Qt\moc_SoQtP.icc | $(QTDIR)\bin\moc -i @SOURCE@ -o @TARGET@ ]*/
 
 #include <Inventor/Qt/SoQt.h>
 #include <Inventor/Qt/SoQtObject.h>
@@ -293,22 +299,20 @@ QTimer * SoQtP::delaytimeouttimer = NULL;
 SoQtP * SoQtP::slotobj = NULL;
 bool SoQtP::didcreatemainwidget = FALSE;
 
-#ifdef HAVE_WIN32_API
+#ifdef HAVE_QT_WIN_USE_SIMPLE_TIMERS
 // Qt 3.3 seems to use simple timers by default. Since simple timers
 // causes idle sensors to trigger only 100 times per second, we set
 // this variable to false in SoQt::init(). pederb, 2004-07-21
 
-// The global qt_win_use_simple_timers variable is defined in Qt 3.0.5
-// and 3.3.1. If linking fails for some version of Qt, we'll add a
-// configure test to test for this variable. Reading the Qt interest
-// archive, it seems like it's ok for application code to modify
-// it though.
+// The global qt_win_use_simple_timers variable is at least defined in
+// Qt 3.0.5 and 3.3.1. Reading the Qt interest archive, it seems like
+// it's ok for application code to modify it though.
 Q_EXPORT extern bool qt_win_use_simple_timers;
-#endif // HAVE_WIN32_API
+#endif // HAVE_QT_WIN_USE_SIMPLE_TIMERS
 
 static void soqt_reset_simple_timers(void)
 {
-#ifdef HAVE_WIN32_API
+#ifdef HAVE_QT_WIN_USE_SIMPLE_TIMERS
   const char * env = SoAny::si()->getenv("SOQT_USE_SIMPLE_TIMERS");
   if (env) {
     qt_win_use_simple_timers = (bool) atoi(env);
@@ -316,7 +320,7 @@ static void soqt_reset_simple_timers(void)
   else {
     qt_win_use_simple_timers = false;
   }
-#endif // HAVE_WIN32_API
+#endif // HAVE_QT_WIN_USE_SIMPLE_TIMERS
 }
 
 #define ENVVAR_NOT_INITED INT_MAX
@@ -653,7 +657,12 @@ public:
         QApplication::sendEvent(focus, &qevent);
       }
     }
+#if (QT_VERSION >= 0x040000)
+    long result = 0;
+    return QApplication::winEventFilter(msg, &result);
+#else
     return QApplication::winEventFilter(msg);
+#endif
   }
 #endif // HAVE_WIN32_API
 };
@@ -751,7 +760,13 @@ SoQt::init(QWidget * toplevelwidget)
       if (SoQtP::DEBUG_X11SYNC) {
         // FIXME: SoDebugError::initClass() not yet invoked! 20021021 mortene.
         SoDebugError::postInfo("SoQt::init", "Turning on X synchronization.");
-        XSynchronize(qt_xdisplay(), True);
+        Display * d;
+#if QT_VERSION < 0x040000 // pre Qt 4
+        d = qt_xdisplay();
+#else // Qt 4.0.0+
+        d = QX11Info::display();
+#endif
+        XSynchronize(d, True);
       }
     }
   }
