@@ -1,7 +1,7 @@
 /**************************************************************************\
  *
  *  This file is part of the Coin 3D visualization library.
- *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
+ *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -16,7 +16,7 @@
  *
  *  See <URL:http://www.coin3d.org/> for more information.
  *
- *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
+ *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
  *  <URL:http://www.sim.no/>.
  *
 \**************************************************************************/
@@ -59,6 +59,10 @@
 #include <config.h>
 #endif // HAVE_CONFIG_H
 
+// FIXME: get rid of this define. We should fix up the compile issues
+// wrt Qt 4 properly. 20050629 mortene.
+#define QT3_SUPPORT
+
 #include <stdlib.h>
 
 #define QT_CLEAN_NAMESPACE 1
@@ -67,6 +71,12 @@
 #include <qframe.h>
 #include <qmetaobject.h>
 
+#ifdef Q_WS_X11
+#if QT_VERSION >= 0x040000 // Qt 4.0.0+
+#include <qx11info_x11.h> // for QX11Info
+#endif // Qt 4.0.0+
+#endif // Q_WS_X11
+
 #include <Inventor/SbTime.h>
 #include <Inventor/errors/SoDebugError.h>
 #include <Inventor/misc/SoBasic.h>
@@ -80,6 +90,8 @@
 #include <Inventor/Qt/widgets/SoQtGLArea.h>
 #include <soqtdefs.h>
 
+// *************************************************************************
+
 #define PRIVATE(obj) ((obj)->pimpl)
 #define PUBLIC(obj) ((obj)->pub)
 
@@ -221,7 +233,6 @@ SoQtGLWidget::buildWidget(QWidget * parent)
 
   PRIVATE(this)->borderwidget->setFrameStyle(QFrame::Panel | QFrame::Raised);
   PRIVATE(this)->borderwidget->setLineWidth(PRIVATE(this)->borderthickness);
-  PRIVATE(this)->borderwidget->setMargin(0);
   PRIVATE(this)->borderwidget->move(0, 0);
 
   // Remember our parent widget so we can use it in tests in the
@@ -678,9 +689,6 @@ SoQtGLWidget::hasNormalGLArea(void) const
 }
 
 // *************************************************************************
-
-#ifndef DOXYGEN_SKIP_THIS
-
 // The private data and code for the SoQtGLWidget.
 
 SoQtGLWidgetP::SoQtGLWidgetP(SoQtGLWidget * o)
@@ -1063,8 +1071,8 @@ SoQtGLWidgetP::buildGLWidget(void)
   //
   // 20031218 mortene.
   //
-  // UPDATE 20040624 mortene: some additional suggestions made to
-  // another SoQt user experiencing the same problems:
+  // UPDATE 20040624 mortene: some additional suggestions made by me
+  // to another SoQt user experiencing the same problems:
   //
   // -------8<------ [snip] -------------------8<------ [snip] ------------
   // As mentioned in the FIXME at SoQtGLWidget.cpp:1014 [i.e. this
@@ -1089,6 +1097,41 @@ SoQtGLWidgetP::buildGLWidget(void)
   // certain features for the QGLWidget?), and b) get assistance from
   // TT's support personnel.
   // -------8<------ [snip] -------------------8<------ [snip] ------------
+  //
+  //
+  // UPDATE 20050201 mortene: our dGB customer found the cause of this
+  // problems. See below. This should be useful to know in case we get
+  // more problem reports about this.
+  // 
+  // -------8<------ [snip] -------------------8<------ [snip] ------------
+  // Subject: Workaround for Sun<->linux problems
+  // To: Morten Eriksen <mortene@sim.no>
+  // Date: Tue, 01 Feb 2005 08:59:12 +0100
+  //
+  // As I have reported previously we have had problems with
+  // applications run on a Sun host and displayed on a linux host (the
+  // "Cannot setup a valid OpenGL canvas" problem in
+  // SoQt/src/Inventor/Qt/SoQtGLWidget.cpp:1089)
+  //
+  // [...]
+  //
+  // It turned out that NVidia's default XF86Config turns off
+  // Xinerama, but the driver does still report to the Sun that
+  // Xinerama is supported. The result is that when the sun starts
+  // sending questions about xinerama, the linux-host fails to answer
+  // them.
+  //
+  // The solution is to change the line
+  //
+  // Option "Xinerama" "off"
+  // to
+  // Option "Xinerama" "on"
+  // in XF86Config.
+  //
+  // The only drawback of this change is that the screen behaves
+  // differently - a maximize does for instance maximize over both
+  // screen instead of one (as before).
+  // -------8<------ [snip] -------------------8<------ [snip] ------------
 
   if (!this->currentglwidget->isValid()) {
     SbString s =
@@ -1206,7 +1249,13 @@ SoQtGLWidgetP::isDirectRendering(void)
                               "Could not get hold of current context.");
     return TRUE;
   }
-  Bool isdirect = glXIsDirect(qt_xdisplay(), ctx);
+  Display * d;
+#if QT_VERSION < 0x040000 // pre Qt 4
+  d = qt_xdisplay();
+#else // Qt 4.0.0+
+  d = QX11Info::display();
+#endif
+  Bool isdirect = glXIsDirect(d, ctx);
   PUBLIC(this)->glUnlockNormal();
   return isdirect ? TRUE : FALSE;
 #else // ! X11
@@ -1214,8 +1263,6 @@ SoQtGLWidgetP::isDirectRendering(void)
 #endif // ! X11
 }
 
-#endif // DOXYGEN_SKIP_THIS
-
 // *************************************************************************
 
 #undef PRIVATE
