@@ -1,7 +1,7 @@
 /**************************************************************************\
  *
  *  This file is part of the Coin 3D visualization library.
- *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
+ *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -16,7 +16,7 @@
  *
  *  See <URL:http://www.coin3d.org/> for more information.
  *
- *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
+ *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
  *  <URL:http://www.sim.no/>.
  *
 \**************************************************************************/
@@ -25,8 +25,12 @@
 #include <config.h>
 #endif // HAVE_CONFIG_H
 
+// FIXME: get rid of this define. We should fix up the compile issues
+// wrt Qt 4 properly. 20050629 mortene.
+#define QT3_SUPPORT
+
 #include <qevent.h>
-#include <qkeycode.h>
+#include <qnamespace.h>
 
 #include <Inventor/SbDict.h>
 #include <Inventor/events/SoKeyboardEvent.h>
@@ -97,9 +101,9 @@ struct SoQtKeyboardP::key1map SoQtKeyboardP::QtToSoMapping[] = {
   {Qt::Key_Up, SoKeyboardEvent::UP_ARROW, '.'},
   {Qt::Key_Right, SoKeyboardEvent::RIGHT_ARROW, '.'},
   {Qt::Key_Down, SoKeyboardEvent::DOWN_ARROW, '.'},
-  {Qt::Key_Prior, SoKeyboardEvent::PRIOR, '.'},
+  {Qt::Key_PageUp, SoKeyboardEvent::PRIOR, '.'},
   {Qt::Key_PageUp, SoKeyboardEvent::PAGE_UP, '.'},
-  {Qt::Key_Next, SoKeyboardEvent::NEXT, '.'},
+  {Qt::Key_PageDown, SoKeyboardEvent::NEXT, '.'},
   {Qt::Key_PageDown, SoKeyboardEvent::PAGE_DOWN, '.'},
 
   {Qt::Key_Shift, SoKeyboardEvent::LEFT_SHIFT, '.'},
