@@ -1,7 +1,7 @@
 /**************************************************************************\
  *
  *  This file is part of the Coin 3D visualization library.
- *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
+ *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -16,22 +16,11 @@
  *
  *  See <URL:http://www.coin3d.org/> for more information.
  *
- *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
+ *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
  *  <URL:http://www.sim.no/>.
  *
 \**************************************************************************/
 
-#include <qpopupmenu.h>
-#include <qmetaobject.h>
-
-#include <Inventor/SoLists.h>
-#include <Inventor/errors/SoDebugError.h>
-
-#include <Inventor/Qt/widgets/QtNativePopupMenu.h>
-#include <Inventor/Qt/widgets/moc_QtNativePopupMenu.icc>
-
-#include <soqtdefs.h>
-
 /*!
   \class QtNativePopupMenu Inventor/Qt/widgets/QtNativePopupMenu.h
   \brief The QtNativePopupMenu class implements a common interface for popup
@@ -40,12 +29,42 @@
 
 // *************************************************************************
 
+// FIXME: get rid of this define. We should fix up the compile issues
+// wrt Qt 4 properly. 20050629 mortene.
+#define QT3_SUPPORT
+
+#include <qmetaobject.h>
+
+// *************************************************************************
+
+// Take care of class name incompatibilities between Qt 3 and Qt 4.
+
+#if QT_VERSION < 0x040000 // pre Qt 4
+#include <qpopupmenu.h>
+#define QPOPUPMENU_CLASS QPopupMenu
+#else // Qt 4.0.0+
+#include <QMenu>
+#define QPOPUPMENU_CLASS QMenu
+#endif // Qt 4.0.0+
+
+// ************************************************************************
+
+#include <Inventor/SoLists.h>
+#include <Inventor/errors/SoDebugError.h>
+
+#include <Inventor/Qt/widgets/QtNativePopupMenu.h>
+#include <Inventor/Qt/widgets/moc_QtNativePopupMenu.icc>
+
+#include <soqtdefs.h>
+
+// *************************************************************************
+
 struct MenuRecord {
   int menuid;
   char * name;
   char * title;
-  QPopupMenu * menu;
-  QPopupMenu * parent;
+  QPOPUPMENU_CLASS * menu;
+  QPOPUPMENU_CLASS * parent;
 }; // struct MenuRecord
 
 struct ItemRecord {
@@ -53,7 +72,7 @@ struct ItemRecord {
   int flags;
   char * name;
   char * title;
-  QPopupMenu * parent;
+  QPOPUPMENU_CLASS * parent;
 }; // struct ItemRecord
 
 #define ITEM_MARKED       0x0001
@@ -297,9 +316,7 @@ QtNativePopupMenu::getMenuItemEnabled(int itemid)
 */
 
 void
-QtNativePopupMenu::_setMenuItemMarked(
-  int itemid,
-  SbBool marked)
+QtNativePopupMenu::_setMenuItemMarked(int itemid, SbBool marked)
 {
   ItemRecord * rec = this->getItemRecord(itemid);
   if (rec == NULL)
@@ -308,11 +325,16 @@ QtNativePopupMenu::_setMenuItemMarked(
     rec->flags |= ITEM_MARKED;
   else
     rec->flags &= ~ITEM_MARKED;
-  if (rec->parent != NULL)
+  if (rec->parent != NULL) {
+#if QT_VERSION >= 0x040000 // Qt 4.*
+    // FIXME: is this really safe? (20050727 frodo)
+    QAction * action = (QAction *) rec->parent->findItem(itemid);
+    if (action) action->setChecked(marked ? true : false);
+#else
     rec->parent->setItemChecked(rec->itemid, marked ? true : false);
-  if (marked)
-    this->setRadioGroupMarkedItem(itemid);
-} // _setMenuItemMarked()
+#endif
+  }
+}
 
 /*!
 */
@@ -342,9 +364,20 @@ QtNativePopupMenu::addMenu(int menuid,
   MenuRecord * sub = this->getMenuRecord(submenuid);
   assert(super && sub && "no such menu");
 
+  // disconnect the submenu from the activated() signal. In Qt 4.0
+  // only the parent menu should be connected, since both the parent
+  // menu and the submenu will generate a call to
+  // itemActivation(). Multiple calls to itemActivation() causes a
+  // segfault when selecting Quadbuffer stereo, at least when it's not
+  // supported. (20050726 frodo)
+#if QT_VERSION >= 0x040000 // Qt 4.*
+  QObject::disconnect(sub->menu, SIGNAL(activated(int)),
+                      this, SLOT(itemActivation(int)));
+#endif
+
   if (pos == -1)
     super->menu->insertItem(QString(sub->title), sub->menu, sub->menuid);
-  else
+  else 
     super->menu->insertItem(QString(sub->title),
                              sub->menu, sub->menuid, pos);
   sub->parent = super->menu;
@@ -368,8 +401,20 @@ QtNativePopupMenu::addMenuItem(int menuid,
   else
     menu->menu->insertItem(QString(item->title), item->itemid, pos);
   item->parent = menu->menu;
-  if (item->flags & ITEM_MARKED)
+
+#if QT_VERSION >= 0x040000 // Qt 4.*
+  // FIXME: is this really safe? (20050726 frodo)
+  QAction * action = (QAction *) item->parent->findItem(itemid);
+  if (action) action->setCheckable(true);
+#endif // Qt 4.*
+  
+  if (item->flags & ITEM_MARKED) {
+#if QT_VERSION >= 0x040000 // Qt 4.*
+    if (action) action->setChecked(true);
+#else
     item->parent->setItemChecked(item->itemid, true);
+#endif
+  }
 } // addMenuItem()
 
 void
@@ -378,7 +423,7 @@ QtNativePopupMenu::addSeparator(int menuid,
 {
   MenuRecord * menu = this->getMenuRecord(menuid);
   assert(menu && "no such menu");
-
+  
   ItemRecord * rec = createItemRecord("separator");
   menu->menu->insertSeparator(pos);
   rec->flags |= ITEM_SEPARATOR;
@@ -505,9 +550,16 @@ QtNativePopupMenu::createMenuRecord(
   rec->menuid = -1;
   rec->name = strcpy(new char [strlen(name)+1], name);
   rec->title = strcpy(new char [strlen(name)+1], name);
-  rec->menu = new QPopupMenu((QWidget *) NULL, name);
+
+#if QT_VERSION >= 0x040000 // Qt 4.*
+  rec->menu = new QPOPUPMENU_CLASS(QString(name));
+#else
+  rec->menu = new QPOPUPMENU_CLASS((QWidget *) NULL, name);
+#endif
+
   QObject::connect(rec->menu, SIGNAL(activated(int)),
-                    this, SLOT(itemActivation(int)));
+                   this, SLOT(itemActivation(int)));
+
   rec->parent = NULL;
   return rec;
 } // create()
