@@ -1,7 +1,7 @@
 /**************************************************************************\
  *
  *  This file is part of the Coin 3D visualization library.
- *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
+ *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -16,7 +16,7 @@
  *
  *  See <URL:http://www.coin3d.org/> for more information.
  *
- *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
+ *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
  *  <URL:http://www.sim.no/>.
  *
 \**************************************************************************/
@@ -31,17 +31,30 @@
 
 #include <assert.h>
 
+// FIXME: get rid of this define. We should fix up the compile issues
+// wrt Qt 4 properly. 20050629 mortene.
+#define QT3_SUPPORT
+
 #include <qmetaobject.h>
+#include <qnamespace.h>
+#include <qevent.h>
 
-#if SOQT_DEBUG
 #include <Inventor/errors/SoDebugError.h>
-#endif // SOQT_DEBUG
 
 #include <Inventor/Qt/widgets/SoQtGLArea.h>
 #include <Inventor/Qt/widgets/moc_SoQtGLArea.icc>
-
 #include <soqtdefs.h>
 
+// ************************************************************************
+
+// Take care of namespace incompatibilities between Qt 3 and Qt 4.
+
+#if QT_VERSION < 0x040000 // pre Qt 4
+#define QTWIDGET_STRONGFOCUS QWidget::StrongFocus
+#else // Qt 4.0.0+
+#define QTWIDGET_STRONGFOCUS Qt::StrongFocus
+#endif // Qt 4.0.0+
+
 // *************************************************************************
 
 #if SOQT_DEBUG && 0 // switch 0<->1 to toggle debugging info on/off
@@ -72,7 +85,7 @@ SoQtGLArea::SoQtGLArea(QGLFormat * const format,
   // The 3rd argument is supposed to be the widget name, but when
   // running on QGL v4.30 and Qt v2.1.0 application code will crash on
   // exit under freak conditions.
-  : inherited(*format, parent, NULL, sharewidget, WResizeNoErase)
+  : inherited(*format, parent, NULL, sharewidget, Qt::WResizeNoErase)
 {
 #if HAVE_QGLWIDGET_SETAUTOBUFFERSWAP
   // We'll handle the OpenGL buffer swapping ourselves, to support the
@@ -83,7 +96,7 @@ SoQtGLArea::SoQtGLArea(QGLFormat * const format,
 #endif // HAVE_QGLWIDGET_SETAUTOBUFFERSWAP
 
   this->keycb = NULL;
-  this->setFocusPolicy(QWidget::StrongFocus);
+  this->setFocusPolicy(QTWIDGET_STRONGFOCUS);
 }
 
 SoQtGLArea::~SoQtGLArea()
@@ -95,7 +108,7 @@ void
 SoQtGLArea::initializeGL(void)
 {
   SOQT_GLAREA_DEBUG_START(initializeGL);
-  this->setBackgroundMode(QWidget::NoBackground); // Avoid unnecessary flicker.
+  this->setBackgroundMode(Qt::NoBackground); // Avoid unnecessary flicker.
   emit this->init_sig();
   SOQT_GLAREA_DEBUG_DONE(initializeGL);
 }
