@@ -1,7 +1,7 @@
 /**************************************************************************\
  *
  *  This file is part of the Coin 3D visualization library.
- *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
+ *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -16,7 +16,7 @@
  *
  *  See <URL:http://www.coin3d.org/> for more information.
  *
- *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
+ *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
  *  <URL:http://www.sim.no/>.
  *
 \**************************************************************************/
@@ -36,11 +36,16 @@
 #include <assert.h>
 #include <stdio.h>
 
+// FIXME: get rid of this define. We should fix up the compile issues
+// wrt Qt 4 properly. 20050629 mortene.
+#define QT3_SUPPORT
+
 #include <qpainter.h>
 #include <qdrawutil.h>
 #include <qimage.h>
 #include <qpixmap.h>
 #include <qmetaobject.h>
+#include <qevent.h>
 
 #include <Inventor/SbBasic.h>
 #include <Inventor/errors/SoDebugError.h>
@@ -153,10 +158,10 @@ SoQtThumbWheel::paintEvent(QPaintEvent * event)
 
   if (this->orient == Vertical)
     bitBlt(this, wheelrect.left(), wheelrect.top(), this->pixmaps[pixmap],
-           0, 0, w, dval, CopyROP);
+           0, 0, w, dval);
   else
     bitBlt(this, wheelrect.left(), wheelrect.top(), this->pixmaps[pixmap],
-           0, 0, dval, w, CopyROP);
+           0, 0, dval, w);
   this->currentPixmap = pixmap;
 }
 
@@ -170,7 +175,7 @@ SoQtThumbWheel::mousePressEvent(QMouseEvent * event)
   if (this->state != SoQtThumbWheel::Idle)
     return;
 
-  if (event->button() != LeftButton)
+  if (event->button() != Qt::LeftButton)
     return;
 
   QRect wheelrect;
@@ -235,7 +240,7 @@ SoQtThumbWheel::mouseReleaseEvent(QMouseEvent * event)
   if (this->state != SoQtThumbWheel::Dragging)
     return;
 
-  if (event->button() != LeftButton)
+  if (event->button() != Qt::LeftButton)
     return;
 
   this->wheelValue = this->tempWheelValue;
